@@ -18,9 +18,9 @@ import collections
 import copy
 import time
 
+from oslo_log import log as logging
 import six
 
-from stackalytics.openstack.common import log as logging
 from stackalytics.processor import launchpad_utils
 from stackalytics.processor import user_processor
 from stackalytics.processor import utils
@@ -180,8 +180,8 @@ class RecordProcessor(object):
         merged_user = {}  # merged user profile
 
         # collect ordinary fields
-        for key in ['seq', 'user_name', 'user_id', 'gerrit_id',
-                    'launchpad_id', 'companies', 'static']:
+        for key in ['seq', 'user_name', 'user_id', 'gerrit_id', 'github_id',
+                    'launchpad_id', 'companies', 'static', 'ldap_id']:
             value = next((v.get(key) for v in user_profiles if v.get(key)),
                          None)
             if value:
