@@ -21,18 +21,31 @@ import six
 import testtools
 
 
+def dict_raise_on_duplicates(ordered_pairs):
+    """Reject duplicate keys."""
+    d = {}
+    for k, v in ordered_pairs:
+        if k in d:
+            raise ValueError("duplicate key: %s (value: %s)" % (k, v))
+        else:
+            d[k] = v
+    return d
+
+
 class TestConfigFiles(testtools.TestCase):
     def setUp(self):
         super(TestConfigFiles, self).setUp()
 
-    def _read_file(self, file_name):
+    def _read_raw_file(self, file_name):
         if six.PY3:
             opener = functools.partial(open, encoding='utf8')
         else:
             opener = open
         with opener(file_name, 'r') as content_file:
-            content = content_file.read()
-            return json.loads(content)
+            return content_file.read()
+
+    def _read_file(self, file_name):
+        return json.loads(self._read_raw_file(file_name))
 
     def _verify_ordering(self, array, key, msg):
         comparator = lambda x, y: (x > y) - (x < y)
@@ -53,6 +66,19 @@ class TestConfigFiles(testtools.TestCase):
         schema = self._read_file('etc/corrections.schema.json')
         jsonschema.validate(corrections, schema)
 
+    def _verify_default_data_duplicate_keys(self, file_name):
+        try:
+            json.loads(self._read_raw_file(file_name),
+                       object_pairs_hook=dict_raise_on_duplicates)
+        except ValueError as ve:
+            self.fail(ve)
+
+    def test_default_data_duplicate_keys(self):
+        self._verify_default_data_duplicate_keys('etc/default_data.json')
+
+    def test_test_default_data_duplicate_keys(self):
+        self._verify_default_data_duplicate_keys('etc/test_default_data.json')
+
     def _verify_default_data_by_schema(self, file_name):
         default_data = self._read_file(file_name)
         schema = self._read_file('etc/default_data.schema.json')
@@ -80,8 +106,10 @@ class TestConfigFiles(testtools.TestCase):
     def _verify_users_in_alphabetical_order(self, file_name):
         users = self._read_file(file_name)['users']
         self._verify_ordering(
-            users, key=lambda x: x['launchpad_id'],
-            msg='List of users should be ordered by launchpad id')
+            users, key=lambda x: (x.get('launchpad_id') or x.get('ldap_id') or
+                                  x.get('github_id')),
+            msg='List of users should be ordered by launchpad id or ldap id '
+                'or github id')
 
     def test_users_in_alphabetical_order(self):
         self._verify_users_in_alphabetical_order('etc/default_data.json')
@@ -128,3 +156,20 @@ class TestConfigFiles(testtools.TestCase):
 
     def test_users_unique_profiles_in_test_file(self):
         self._verify_users_unique('etc/test_default_data.json')
+
+    def _verify_default_data_whitespace_issues(self, file_name):
+        data = self._read_raw_file(file_name)
+        line_n = 1
+        for line in data.split('\n'):
+            msg = 'Whitespace issue in "%s", line %s: ' % (line, line_n)
+            self.assertTrue(line.find('\t') == -1, msg=msg + 'tab character')
+            self.assertEqual(line.rstrip(), line,
+                             message=msg + 'trailing spaces')
+            line_n += 1
+
+    def test_default_data_whitespace_issues(self):
+        self._verify_default_data_whitespace_issues('etc/default_data.json')
+
+    def test_test_default_data_whitespace_issues(self):
+        self._verify_default_data_whitespace_issues(
+            'etc/test_default_data.json')
